from setuptools import setup
from distutils.command.build_py import build_py
import subprocess
import os


class APIGenBuild(build_py):
    def run(self):
        build_versions = ['3.0', '3.1', '3.2', '4.0']
        default_version = '4.0'
        environ = os.environ.copy()
        if not environ.get('NETDB_TOKEN', False):
            build_versions.remove('3.0')
        for version in build_versions:
            target_dir = os.path.join(self.build_lib, 'netdb_client', f"api{version.replace('.', '')}")
            self.mkpath(target_dir)
            environ['NETDB_VERSION'] = version
            subprocess.run(['net-api-generator', 'python', f'--output-dir={target_dir}'], check=True, env=environ)
        target_dir = os.path.join(self.build_lib, 'netdb_client')
        environ['NETDB_VERSION'] = default_version
        subprocess.run(['net-api-generator', 'python', f'--output-dir={target_dir}'], check=True, env=environ)
        build_py.run(self)
        

setup(
    name='netdb_client',
    version='4.0',
    author='Dr. Meta',
    description='This is a meta package to install the automatically generated NET-API 3.0, 3.1, 3.2 and 4.0 definitions.',
    url='https://git.scc.kit.edu/scc-net/net-suite/netdb-client-lib',
    install_requires=['requests'],
    python_requires='>=3.7',
    packages=['netdb_client'],
    cmdclass={'build_py': APIGenBuild}
)

